@@ -17,7 +17,7 @@
 #' @examples 
 #' data(boston)
 #' bostint<-fgeninter(boston[,1:13],2)[[1]]
-#' a<-f2st(boston[,14],bostint,lm=3,sub=TRUE)
+#' a<-f2st(boston[,14],bostint,lm=3,sub=FALSE)
 f2st<-function(y,x,p0=0.01,nu=1,kmn=0,kmx=0,kex=0,mx=21,lm=9^9,sub=T,inr=T,xinr=F,qq=0){
 	kxx<-kex
 	kmmx<-kmx
@@ -36,7 +36,7 @@ f2st<-function(y,x,p0=0.01,nu=1,kmn=0,kmx=0,kex=0,mx=21,lm=9^9,sub=T,inr=T,xinr=
 	qqq<-qq
 	pvv<- matrix(c(0,0,0,0,0),nrow=1)
 	while(kv>0.5){
-		tmp<-f1st(y,x,p0=p0,nu=nu,kmn=kmnn,kmx=kmmx,kex=kxx,mx=mx,sub=sub,inr=inr,xinr=xinr,qq=0)[[1]]
+		tmp<-f1st(y,x,p0=p0,nu=nu,kmn=kmnn,kmx=kmmx,kex=kxx,mx=mx,sub=sub,inr=inr,xinr=xinr,qq=qq)[[1]]
 		if(tmp[1,1]<=0){kv<-0}
 		if(kv>0.5){
 			lv<-length(tmp[,1])
